# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from public_api_server_connector.models.http_method import HttpMethod

class ApiLogGet(BaseModel):
    """
    ApiLogGet
    """
    origin: StrictStr = Field(...)
    method: HttpMethod = Field(...)
    url: StrictStr = Field(...)
    action: StrictStr = Field(...)
    payload: Optional[StrictStr] = None
    status_code: StrictInt = Field(...)
    response: StrictStr = Field(...)
    id: StrictInt = Field(...)
    created_at: StrictInt = Field(...)
    __properties = ["origin", "method", "url", "action", "payload", "status_code", "response", "id", "created_at"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiLogGet:
        """Create an instance of ApiLogGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiLogGet:
        """Create an instance of ApiLogGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiLogGet.parse_obj(obj)

        _obj = ApiLogGet.parse_obj({
            "origin": obj.get("origin"),
            "method": obj.get("method"),
            "url": obj.get("url"),
            "action": obj.get("action"),
            "payload": obj.get("payload"),
            "status_code": obj.get("status_code"),
            "response": obj.get("response"),
            "id": obj.get("id"),
            "created_at": obj.get("created_at")
        })
        return _obj


